@@ -263,13 +263,17 @@ class DobissOutput(DobissEntity):
         else:
             await self.turn_on()
 
-    async def turn_on(self, brightness=100, delayon=None, delayoff=None):
+    async def turn_on(
+        self, brightness=100, delayon=None, delayoff=None, from_pir=False
+    ):
         """Instruct the entity to turn on.
         You can skip the brightness part if your entity does not support
         brightness control.
         """
         if self._dimmable:
             value = brightness
+        elif from_pir:
+            value = 9
         else:
             value = 1
         await self._dobiss.action(
@@ -828,7 +832,7 @@ class DobissAPI:
     async def update_from_status(self, status, force=False):
         # looks like in dobiss NXT 3.20 status updates for the NXT module can come it without address.
         if type(status) == list and len(status) == 1:
-            status = {'0': status[0]}
+            status = {"0": status[0]}
         for e in self._devices:
             await e.update_from_global(status, force)
 
